#ifndef X13_H
#define X13_H

#ifdef __cplusplus
extern "C" {
#endif

void deeponion_x13_hash(const char* input, char* output);

#ifdef __cplusplus
}
#endif

#endif
